import type { PointSize, IDrawOptions, IDrawSettings, Data, ViewSizeInfo, ViewScaleInfo, ElementType, Element, RecursivePartial, ElementPosition } from '@idraw/types';
import type { IDrawEvent } from './event';
import type { ExportImageFileBaseOptions, ExportImageFileResult } from './file';
export declare class iDraw {
    #private;
    constructor(mount: HTMLDivElement, options: IDrawOptions);
    reset(opts: IDrawSettings): void;
    setData(data: Data): void;
    getData(opts?: {
        compact?: boolean;
    }): Data | null;
    getViewInfo(): {
        viewSizeInfo: ViewSizeInfo;
        viewScaleInfo: ViewScaleInfo;
    };
    scale(opts: {
        scale: number;
        point: PointSize;
    }): void;
    setViewScale(opts: {
        scale: number;
        offsetX: number;
        offsetY: number;
    }): void;
    centerContent(opts?: {
        data?: Data;
    }): void;
    resize(opts: Partial<ViewSizeInfo>): void;
    on<T extends keyof IDrawEvent>(name: T, callback: (e: IDrawEvent[T]) => void): void;
    off<T extends keyof IDrawEvent>(name: T, callback: (e: IDrawEvent[T]) => void): void;
    trigger<T extends keyof IDrawEvent>(name: T, e?: IDrawEvent[T]): void;
    selectElement(uuid: string): void;
    selectElements(uuids: string[]): void;
    selectElementByPosition(position: ElementPosition): void;
    selectElementsByPositions(positions: ElementPosition[]): void;
    cancelElements(): void;
    createElement<T extends ElementType>(type: T, opts?: {
        element?: RecursivePartial<Element<T>>;
        viewCenter?: boolean;
    }): Element<T>;
    updateElement(element: Element): void;
    addElement(element: Element, opts?: {
        position: ElementPosition;
    }): Data;
    deleteElement(uuid: string): void;
    moveElement(uuid: string, to: ElementPosition): void;
    getImageBlobURL(opts: ExportImageFileBaseOptions): Promise<ExportImageFileResult>;
    isDestroyed(): boolean;
    destroy(): void;
    getViewCenter(): PointSize;
    $onBoardWatcherEvents(): void;
    $offBoardWatcherEvents(): void;
}
